==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/client/render/feature/FrostologerEyesFeatureRenderer.java <==
package com.github.thedeathlycow.frostiful.client.render.feature;

import com.github.thedeathlycow.frostiful.client.model.FrostologerEntityModel;
import com.github.thedeathlycow.frostiful.entity.frostologer.FrostologerEntity;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;

@Environment(EnvType.CLIENT)
public class FrostologerEyesFeatureRenderer<T extends FrostologerEntity, M extends FrostologerEntityModel<T>> extends class_3887<T, M> {

    private final class_1921 skin;

    public FrostologerEyesFeatureRenderer(class_3883<T, M> context, class_2960 id) {
        super(context);
        this.skin = class_1921.method_42600(id);
    }

    @Override
    public void render(class_4587 matrices, class_4597 vertexConsumers, int light, T entity, float limbAngle, float limbDistance, float tickDelta, float animationProgress, float headYaw, float headPitch) {
        if (entity.isAtMaxPower()) {
            class_4588 vertexConsumer = vertexConsumers.getBuffer(this.skin);
            this.method_17165()
                    .method_60879(
                            matrices,
                            vertexConsumer,
                            0x00F000F0,
                            class_4608.field_21444
                    );
        }
    }

}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/client/render/feature/FrostologerEyesFeatureRenderer.java <==
package com.github.thedeathlycow.frostiful.client.render.feature;

import com.github.thedeathlycow.frostiful.client.render.model.FrostologerEntityModel;
import com.github.thedeathlycow.frostiful.client.render.state.FrostologerEntityRenderState;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;

@Environment(EnvType.CLIENT)
public class FrostologerEyesFeatureRenderer<T extends FrostologerEntityRenderState, M extends FrostologerEntityModel<T>> extends class_3887<T, M> {

    private final class_1921 skin;

    public FrostologerEyesFeatureRenderer(class_3883<T, M> context, class_2960 id) {
        super(context);
        this.skin = class_1921.method_42600(id);
    }

    public void render(
            class_4587 matrices,
            class_4597 vertexConsumers,
            int light,
            T state,
            float limbAngle,
            float limbDistance
    ) {
        if (state.glowingEyes) {
            class_4588 vertexConsumer = vertexConsumers.getBuffer(this.skin);
            this.method_17165()
                    .method_60879(
                            matrices,
                            vertexConsumer,
                            0x00F000F0,
                            class_4608.field_21444
                    );
        }
    }
}
